import static com.silanis.esl.sdk.builder.DocumentBuilder.newDocumentWithName;
import static com.silanis.esl.sdk.builder.PackageBuilder.newPackageNamed;
import static com.silanis.esl.sdk.builder.SignatureBuilder.signatureFor;
import static com.silanis.esl.sdk.builder.SignerBuilder.newSignerWithEmail;

import java.util.List;
import java.util.Map;

import com.silanis.esl.sdk.DocumentPackage;
import com.silanis.esl.sdk.EslClient;
import com.silanis.esl.sdk.PackageId;
import com.silanis.esl.sdk.Reminder;
import com.silanis.esl.sdk.ReminderSchedule;
import com.silanis.esl.sdk.Sender;
import com.silanis.esl.sdk.TextAnchorPosition;
import com.silanis.esl.sdk.builder.FieldBuilder;
import com.silanis.esl.sdk.builder.ReminderScheduleBuilder;
import com.silanis.esl.sdk.builder.TextAnchorBuilder;

public class settingUpReminders {

	//replace api_key placeholder with your own value
	private static String API_KEY = "api_key";
	private static String API_URL = "https://sandbox.e-signlive.com/api";
	public static ReminderSchedule reminderScheduleToCreate;
	public static ReminderSchedule reminderScheduleToUpdate;
    public static ReminderSchedule createdReminderSchedule, updatedReminderSchedule, removedReminderSchedule;
	
	public static void main(String[] args) {
		
		EslClient eslClient = new EslClient(API_KEY, API_URL);
		
		DocumentPackage superDuperPackage3 = newPackageNamed("Text Anchor Extraction Example Java SDK")
		         .withSigner(newSignerWithEmail("john.smith@example.com") 
			              .withFirstName("John")
			              .withLastName("Smith")
			              .withCustomId("client"))
		         .withDocument(newDocumentWithName("Sample Contract")
		              .fromFile("DOC_FILE_PATH")
		              .enableExtraction()
		              .withSignature(signatureFor("john.smith@example.com")
		                   .withPositionAnchor(TextAnchorBuilder.newTextAnchor("Signature of the Client")
		                        .atPosition(TextAnchorPosition.TOPLEFT)
		                        .withSize(150, 40)
		                        .withOffset(0, -50)
		                        .withCharacter(0)
		                        .withOccurence(0))
		                   .withField(FieldBuilder.signerName()
		                		   	.withPositionAnchor(TextAnchorBuilder.newTextAnchor("(hereafter referred to as")
			                             .atPosition(TextAnchorPosition.TOPRIGHT)
			                             .withSize(150, 20)
			                             .withOffset(-175, -5)
			                             .withCharacter(0)
			                             .withOccurence(0)))
		                   .withField(FieldBuilder.signatureDate()
			                        .withPositionAnchor(TextAnchorBuilder.newTextAnchor("Date")
			                             .atPosition(TextAnchorPosition.TOPRIGHT)
			                             .withSize(75, 40)
			                             .withCharacter(4)
			                             .withOffset(10, -30)
			                             .withOccurence(0)))))
		              .build();
	
		PackageId packageId = eslClient.createPackage(superDuperPackage3);
		
		//create reminder schedule
		reminderScheduleToCreate = ReminderScheduleBuilder.forPackageWithId( packageId )
                .withDaysUntilFirstReminder( 2 )
                .withDaysBetweenReminders( 1 )
                .withNumberOfRepetitions( 5 )
                .build();

		eslClient.getReminderService().createReminderScheduleForPackage( reminderScheduleToCreate );
		
		eslClient.sendPackage( packageId );
		
		//retrieve reminder schedule
		ReminderSchedule reminderSchedule = eslClient.getReminderService().getReminderScheduleForPackage(packageId);
		
		//update reminder schedule
		reminderScheduleToUpdate = ReminderScheduleBuilder.forPackageWithId( packageId )
                .withDaysUntilFirstReminder( 2 )
                .withDaysBetweenReminders( 1 )
                .withNumberOfRepetitions( 5 )
                .build();
		
		eslClient.getReminderService().updateReminderScheduleForPackage(reminderScheduleToUpdate);
		
		//retrieve reminders sent to signers
		List<Reminder> reminders = reminderSchedule.getReminders();
		
		for (Reminder reminder : reminders) {
			System.out.println(reminder.getSentDate());
		}
		
		//clear reminder schedule
		eslClient.getReminderService().clearReminderScheduleForPackage(packageId);
	}
}
